Henri Verbeet : wined3d: Use wined3d_texture_blt() in surface_upload_from_surface().

Alexandre Julliard julliard at winehq.org
Tue Mar 7 15:43:59 CST 2017


Module: wine
Branch: master
Commit: aaa431d8a8a31c48aee73c0f423a0389bf518b22
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=aaa431d8a8a31c48aee73c0f423a0389bf518b22

Author: Henri Verbeet <hverbeet at codeweavers.com>
Date:   Tue Mar  7 08:57:25 2017 +0100

wined3d: Use wined3d_texture_blt() in surface_upload_from_surface().

Signed-off-by: Henri Verbeet <hverbeet at codeweavers.com>
Signed-off-by: Alexandre Julliard <julliard at winehq.org>

---

 dlls/wined3d/surface.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/dlls/wined3d/surface.c b/dlls/wined3d/surface.c
index 3e95876..a2a7d98 100644
--- a/dlls/wined3d/surface.c
+++ b/dlls/wined3d/surface.c
@@ -1098,9 +1098,10 @@ HRESULT surface_upload_from_surface(struct wined3d_surface *dst_surface, const P
         return WINED3DERR_INVALIDCALL;
     }
 
     /* Use wined3d_surface_blt() instead of uploading directly if we need conversion. */
     if (dst_format->convert || wined3d_format_get_color_key_conversion(dst_texture, FALSE))
-        return wined3d_surface_blt(dst_surface, &dst_rect, src_surface, src_rect, 0, NULL, WINED3D_TEXF_POINT);
+        return wined3d_texture_blt(dst_texture, dst_sub_resource_idx, &dst_rect,
+                src_texture, src_sub_resource_idx, src_rect, 0, NULL, WINED3D_TEXF_POINT);
 
     context = context_acquire(dst_texture->resource.device, NULL, 0);
     gl_info = context->gl_info;
@@ -1098,9 +1098,10 @@ HRESULT surface_upload_from_surface(struct wined3d_surface *dst_surface, const P
     }
 
-    /* Use wined3d_surface_blt() instead of uploading directly if we need conversion. */
+    /* Use wined3d_texture_blt() instead of uploading directly if we need conversion. */
     if (dst_format->convert || wined3d_format_get_color_key_conversion(dst_texture, FALSE))




More information about the wine-cvs mailing list